==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ResourceTypeRegistrationPropertiesManagementArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesManagementArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property incidentContactEmail
 * @property incidentRoutingService
 * @property incidentRoutingTeam
 * @property manifestOwners
 * @property resourceAccessPolicy
 * @property resourceAccessRoles
 * @property schemaOwners
 * @property serviceTreeInfos
 */
public data class ResourceTypeRegistrationPropertiesManagementArgs(
    public val incidentContactEmail: Output<String>? = null,
    public val incidentRoutingService: Output<String>? = null,
    public val incidentRoutingTeam: Output<String>? = null,
    public val manifestOwners: Output<List<String>>? = null,
    public val resourceAccessPolicy: Output<String>? = null,
    public val resourceAccessRoles: Output<List<Any>>? = null,
    public val schemaOwners: Output<List<String>>? = null,
    public val serviceTreeInfos: Output<List<ServiceTreeInfoArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesManagementArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesManagementArgs =
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesManagementArgs.builder()
            .incidentContactEmail(incidentContactEmail?.applyValue({ args0 -> args0 }))
            .incidentRoutingService(incidentRoutingService?.applyValue({ args0 -> args0 }))
            .incidentRoutingTeam(incidentRoutingTeam?.applyValue({ args0 -> args0 }))
            .manifestOwners(manifestOwners?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .resourceAccessPolicy(resourceAccessPolicy?.applyValue({ args0 -> args0 }))
            .resourceAccessRoles(resourceAccessRoles?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .schemaOwners(schemaOwners?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .serviceTreeInfos(
                serviceTreeInfos?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ResourceTypeRegistrationPropertiesManagementArgs].
 */
@PulumiTagMarker
public class ResourceTypeRegistrationPropertiesManagementArgsBuilder internal constructor() {
    private var incidentContactEmail: Output<String>? = null

    private var incidentRoutingService: Output<String>? = null

    private var incidentRoutingTeam: Output<String>? = null

    private var manifestOwners: Output<List<String>>? = null

    private var resourceAccessPolicy: Output<String>? = null

    private var resourceAccessRoles: Output<List<Any>>? = null

    private var schemaOwners: Output<List<String>>? = null

    private var serviceTreeInfos: Output<List<ServiceTreeInfoArgs>>? = null

    /**
     * @param value
     */
    @JvmName("ckjnjrvkelrdrwdc")
    public suspend fun incidentContactEmail(`value`: Output<String>) {
        this.incidentContactEmail = value
    }

    /**
     * @param value
     */
    @JvmName("xffqbajqrkfujwbk")
    public suspend fun incidentRoutingService(`value`: Output<String>) {
        this.incidentRoutingService = value
    }

    /**
     * @param value
     */
    @JvmName("erxlwfixdpwwrctq")
    public suspend fun incidentRoutingTeam(`value`: Output<String>) {
        this.incidentRoutingTeam = value
    }

    /**
     * @param value
     */
    @JvmName("eqhkbgmntxcymbvp")
    public suspend fun manifestOwners(`value`: Output<List<String>>) {
        this.manifestOwners = value
    }

    @JvmName("vmvpqaetlquitngo")
    public suspend fun manifestOwners(vararg values: Output<String>) {
        this.manifestOwners = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("hagnyrigdyinahtr")
    public suspend fun manifestOwners(values: List<Output<String>>) {
        this.manifestOwners = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("tbgybskmcysmunsh")
    public suspend fun resourceAccessPolicy(`value`: Output<String>) {
        this.resourceAccessPolicy = value
    }

    /**
     * @param value
     */
    @JvmName("tenjbdriywxfmowi")
    public suspend fun resourceAccessRoles(`value`: Output<List<Any>>) {
        this.resourceAccessRoles = value
    }

    @JvmName("mdduaxdwvvkvryck")
    public suspend fun resourceAccessRoles(vararg values: Output<Any>) {
        this.resourceAccessRoles = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("aschlfrgeysegmwn")
    public suspend fun resourceAccessRoles(values: List<Output<Any>>) {
        this.resourceAccessRoles = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("ibwjslukqlucpayn")
    public suspend fun schemaOwners(`value`: Output<List<String>>) {
        this.schemaOwners = value
    }

    @JvmName("xxsvlsersxjxafbk")
    public suspend fun schemaOwners(vararg values: Output<String>) {
        this.schemaOwners = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("koqbmacgkelwmqkx")
    public suspend fun schemaOwners(values: List<Output<String>>) {
        this.schemaOwners = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("tysmlonjclcfmsvg")
    public suspend fun serviceTreeInfos(`value`: Output<List<ServiceTreeInfoArgs>>) {
        this.serviceTreeInfos = value
    }

    @JvmName("nlcsnwpuymjuffru")
    public suspend fun serviceTreeInfos(vararg values: Output<ServiceTreeInfoArgs>) {
        this.serviceTreeInfos = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("vnyrhbyohmncjniq")
    public suspend fun serviceTreeInfos(values: List<Output<ServiceTreeInfoArgs>>) {
        this.serviceTreeInfos = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("ieggrrrbrxnynixi")
    public suspend fun incidentContactEmail(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.incidentContactEmail = mapped
    }

    /**
     * @param value
     */
    @JvmName("fjghyrnyghjdwtbc")
    public suspend fun incidentRoutingService(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.incidentRoutingService = mapped
    }

    /**
     * @param value
     */
    @JvmName("eggkhflnrvxuebds")
    public suspend fun incidentRoutingTeam(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.incidentRoutingTeam = mapped
    }

    /**
     * @param value
     */
    @JvmName("nfbttxrbjrwgdhcm")
    public suspend fun manifestOwners(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.manifestOwners = mapped
    }

    /**
     * @param values
     */
    @JvmName("hvrxxfecvyjwtngu")
    public suspend fun manifestOwners(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.manifestOwners = mapped
    }

    /**
     * @param value
     */
    @JvmName("cqntuqslhoaeuysl")
    public suspend fun resourceAccessPolicy(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceAccessPolicy = mapped
    }

    /**
     * @param value
     */
    @JvmName("lniabobmvojdanmu")
    public suspend fun resourceAccessRoles(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceAccessRoles = mapped
    }

    /**
     * @param values
     */
    @JvmName("iyrwhodqgduiaeou")
    public suspend fun resourceAccessRoles(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceAccessRoles = mapped
    }

    /**
     * @param value
     */
    @JvmName("asbksvhxghuymfgn")
    public suspend fun schemaOwners(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.schemaOwners = mapped
    }

    /**
     * @param values
     */
    @JvmName("lrekfdauipqfcpuk")
    public suspend fun schemaOwners(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.schemaOwners = mapped
    }

    /**
     * @param value
     */
    @JvmName("myxncyjvrqmapodk")
    public suspend fun serviceTreeInfos(`value`: List<ServiceTreeInfoArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceTreeInfos = mapped
    }

    /**
     * @param argument
     */
    @JvmName("peiabvdyxydiflhe")
    public suspend
    fun serviceTreeInfos(argument: List<suspend ServiceTreeInfoArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ServiceTreeInfoArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.serviceTreeInfos = mapped
    }

    /**
     * @param argument
     */
    @JvmName("sndasfvcitpvwqyk")
    public suspend fun serviceTreeInfos(
        vararg
        argument: suspend ServiceTreeInfoArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ServiceTreeInfoArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.serviceTreeInfos = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ktbevrrfahhekmmb")
    public suspend fun serviceTreeInfos(argument: suspend ServiceTreeInfoArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ServiceTreeInfoArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.serviceTreeInfos = mapped
    }

    /**
     * @param values
     */
    @JvmName("kfdlrvbgjqppaqpq")
    public suspend fun serviceTreeInfos(vararg values: ServiceTreeInfoArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.serviceTreeInfos = mapped
    }

    internal fun build(): ResourceTypeRegistrationPropertiesManagementArgs =
        ResourceTypeRegistrationPropertiesManagementArgs(
            incidentContactEmail = incidentContactEmail,
            incidentRoutingService = incidentRoutingService,
            incidentRoutingTeam = incidentRoutingTeam,
            manifestOwners = manifestOwners,
            resourceAccessPolicy = resourceAccessPolicy,
            resourceAccessRoles = resourceAccessRoles,
            schemaOwners = schemaOwners,
            serviceTreeInfos = serviceTreeInfos,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ResourceTypeRegistrationPropertiesManagementArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesManagementArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property incidentContactEmail
 * @property incidentRoutingService
 * @property incidentRoutingTeam
 * @property manifestOwners
 * @property resourceAccessPolicy
 * @property resourceAccessRoles
 * @property schemaOwners
 * @property serviceTreeInfos
 */
public data class ResourceTypeRegistrationPropertiesManagementArgs(
    public val incidentContactEmail: Output<String>? = null,
    public val incidentRoutingService: Output<String>? = null,
    public val incidentRoutingTeam: Output<String>? = null,
    public val manifestOwners: Output<List<String>>? = null,
    public val resourceAccessPolicy: Output<String>? = null,
    public val resourceAccessRoles: Output<List<Any>>? = null,
    public val schemaOwners: Output<List<String>>? = null,
    public val serviceTreeInfos: Output<List<ServiceTreeInfoArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesManagementArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesManagementArgs =
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesManagementArgs.builder()
            .incidentContactEmail(incidentContactEmail?.applyValue({ args0 -> args0 }))
            .incidentRoutingService(incidentRoutingService?.applyValue({ args0 -> args0 }))
            .incidentRoutingTeam(incidentRoutingTeam?.applyValue({ args0 -> args0 }))
            .manifestOwners(manifestOwners?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .resourceAccessPolicy(resourceAccessPolicy?.applyValue({ args0 -> args0 }))
            .resourceAccessRoles(resourceAccessRoles?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .schemaOwners(schemaOwners?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .serviceTreeInfos(
                serviceTreeInfos?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ResourceTypeRegistrationPropertiesManagementArgs].
 */
@PulumiTagMarker
public class ResourceTypeRegistrationPropertiesManagementArgsBuilder internal constructor() {
    private var incidentContactEmail: Output<String>? = null

    private var incidentRoutingService: Output<String>? = null

    private var incidentRoutingTeam: Output<String>? = null

    private var manifestOwners: Output<List<String>>? = null

    private var resourceAccessPolicy: Output<String>? = null

    private var resourceAccessRoles: Output<List<Any>>? = null

    private var schemaOwners: Output<List<String>>? = null

    private var serviceTreeInfos: Output<List<ServiceTreeInfoArgs>>? = null

    /**
     * @param value
     */
    @JvmName("sikpnjyogydxtjvt")
    public suspend fun incidentContactEmail(`value`: Output<String>) {
        this.incidentContactEmail = value
    }

    /**
     * @param value
     */
    @JvmName("bytvkqveymyuoqnk")
    public suspend fun incidentRoutingService(`value`: Output<String>) {
        this.incidentRoutingService = value
    }

    /**
     * @param value
     */
    @JvmName("ruogeaqffsyjamdq")
    public suspend fun incidentRoutingTeam(`value`: Output<String>) {
        this.incidentRoutingTeam = value
    }

    /**
     * @param value
     */
    @JvmName("plybkofkmopdhvey")
    public suspend fun manifestOwners(`value`: Output<List<String>>) {
        this.manifestOwners = value
    }

    @JvmName("hxbkdahyutrrknem")
    public suspend fun manifestOwners(vararg values: Output<String>) {
        this.manifestOwners = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("tmukvlflhuvmecbu")
    public suspend fun manifestOwners(values: List<Output<String>>) {
        this.manifestOwners = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("jbjktdkngnavfeky")
    public suspend fun resourceAccessPolicy(`value`: Output<String>) {
        this.resourceAccessPolicy = value
    }

    /**
     * @param value
     */
    @JvmName("msgssqupdbrnpndg")
    public suspend fun resourceAccessRoles(`value`: Output<List<Any>>) {
        this.resourceAccessRoles = value
    }

    @JvmName("icvxguocndvbpwdg")
    public suspend fun resourceAccessRoles(vararg values: Output<Any>) {
        this.resourceAccessRoles = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("nytryudrrxpvntal")
    public suspend fun resourceAccessRoles(values: List<Output<Any>>) {
        this.resourceAccessRoles = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("qqvlkcealarycsvy")
    public suspend fun schemaOwners(`value`: Output<List<String>>) {
        this.schemaOwners = value
    }

    @JvmName("utgqjpintomkjxgm")
    public suspend fun schemaOwners(vararg values: Output<String>) {
        this.schemaOwners = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("pnnubdihqvlpmtno")
    public suspend fun schemaOwners(values: List<Output<String>>) {
        this.schemaOwners = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("ikxyoaoxioidfkeu")
    public suspend fun serviceTreeInfos(`value`: Output<List<ServiceTreeInfoArgs>>) {
        this.serviceTreeInfos = value
    }

    @JvmName("txpxhygnntikmlel")
    public suspend fun serviceTreeInfos(vararg values: Output<ServiceTreeInfoArgs>) {
        this.serviceTreeInfos = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("aqheygkvwnmjabai")
    public suspend fun serviceTreeInfos(values: List<Output<ServiceTreeInfoArgs>>) {
        this.serviceTreeInfos = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("xotjlttwixcydpmc")
    public suspend fun incidentContactEmail(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.incidentContactEmail = mapped
    }

    /**
     * @param value
     */
    @JvmName("fxawxgottimnrijf")
    public suspend fun incidentRoutingService(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.incidentRoutingService = mapped
    }

    /**
     * @param value
     */
    @JvmName("pngphtliwvaxyerc")
    public suspend fun incidentRoutingTeam(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.incidentRoutingTeam = mapped
    }

    /**
     * @param value
     */
    @JvmName("ormsrospucgqoguk")
    public suspend fun manifestOwners(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.manifestOwners = mapped
    }

    /**
     * @param values
     */
    @JvmName("ebpmfxqxveoybkkj")
    public suspend fun manifestOwners(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.manifestOwners = mapped
    }

    /**
     * @param value
     */
    @JvmName("wasqaqkbtywtkimo")
    public suspend fun resourceAccessPolicy(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceAccessPolicy = mapped
    }

    /**
     * @param value
     */
    @JvmName("dtfexwpwvxxmgqqs")
    public suspend fun resourceAccessRoles(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceAccessRoles = mapped
    }

    /**
     * @param values
     */
    @JvmName("vgpvwuotcmvphvhr")
    public suspend fun resourceAccessRoles(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceAccessRoles = mapped
    }

    /**
     * @param value
     */
    @JvmName("vnjhaywviobutfpy")
    public suspend fun schemaOwners(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.schemaOwners = mapped
    }

    /**
     * @param values
     */
    @JvmName("ydbwbctasibmvhtr")
    public suspend fun schemaOwners(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.schemaOwners = mapped
    }

    /**
     * @param value
     */
    @JvmName("jsfgkqtrwidjwqtw")
    public suspend fun serviceTreeInfos(`value`: List<ServiceTreeInfoArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceTreeInfos = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ryrmfkjaoxbmpffe")
    public suspend
    fun serviceTreeInfos(argument: List<suspend ServiceTreeInfoArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ServiceTreeInfoArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.serviceTreeInfos = mapped
    }

    /**
     * @param argument
     */
    @JvmName("bftvqqdqfqvpdcvb")
    public suspend fun serviceTreeInfos(
        vararg
        argument: suspend ServiceTreeInfoArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ServiceTreeInfoArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.serviceTreeInfos = mapped
    }

    /**
     * @param argument
     */
    @JvmName("phjjjgysdpehuums")
    public suspend fun serviceTreeInfos(argument: suspend ServiceTreeInfoArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ServiceTreeInfoArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.serviceTreeInfos = mapped
    }

    /**
     * @param values
     */
    @JvmName("wpjpdomltctrijkq")
    public suspend fun serviceTreeInfos(vararg values: ServiceTreeInfoArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.serviceTreeInfos = mapped
    }

    internal fun build(): ResourceTypeRegistrationPropertiesManagementArgs =
        ResourceTypeRegistrationPropertiesManagementArgs(
            incidentContactEmail = incidentContactEmail,
            incidentRoutingService = incidentRoutingService,
            incidentRoutingTeam = incidentRoutingTeam,
            manifestOwners = manifestOwners,
            resourceAccessPolicy = resourceAccessPolicy,
            resourceAccessRoles = resourceAccessRoles,
            schemaOwners = schemaOwners,
            serviceTreeInfos = serviceTreeInfos,
        )
}
